pycocoa.sets.FrozenSet

Package pycocoa :: Module sets :: Class FrozenSet |
[frames] | no frames]

# Class FrozenSet

                  object --+
                           |
                   frozenset --+
                               |
              object --+       |
                       |       |
    internals._Objectype --+   |
                           |   |
            baseTypes._Type0 --+
                               |
                              FrozenSet

Python `frozenset` Type, wrapping an immutable ObjC `NSSet`.

Instance Methods
copy(self) Make a copy of this frozen set. |
Inherited from `frozenset`: `__and__`, `__cmp__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__hash__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__ne__`, `__or__`, `__rand__`, `__reduce__`, `__repr__`, `__ror__`, `__rsub__`, `__rxor__`, `__sizeof__`, `__sub__`, `__xor__`, `difference`, `intersection`, `isdisjoint`, `issubset`, `issuperset`, `symmetric_difference`, `union` Inherited from `baseTypes._Type0`: `__init__`, `__str__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, ns_frozenset=`(``)`) New FrozenSet from a `frozenset`, `list`, `set`, `tuple`, FrozenSet or `NSSet`. |

Properties
| NS Get the ObjC instance (`NSSet`).
Inherited from `baseTypes._Type0`: `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __new__(cls, ns_frozenset=`(``)`) Static Method |
New FrozenSet from a `frozenset`, `list`, `set`, `tuple`, FrozenSet or `NSSet`. Returns: a new object with type S, a subtype of T Overrides: object.__new__

### copy(self) |
Make a copy of this frozen set. Returns: The copy (FrozenSet). Overrides: frozenset.copy

Property Details

### NS Get the ObjC instance (`NSSet`). Get Method: NS(self) - Get the ObjC instance (`NSSet`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.